searchData={"items":[{"type":"module","title":"HyperLLM.Chat","doc":"HypperLLM.Chat is a single interface for interacting with LLM providers.\nThe interface uses the OpenAI chat completion API. https://platform.openai.com/docs/api-reference/chat","ref":"HyperLLM.Chat.html"},{"type":"module","title":"Example - HyperLLM.Chat","doc":"A Liveview that sends messages to the chat and updates the chat with the response.\n\n    defmodule ChatLive do\n      use Phoenix.LiveView\n\n      def mount(params, session, socket) do\n        {:ok,\n        socket\n        |> assign(chat: HyperLLM.Chat.start(model: \"gpt-4o-mini\"))}\n      end\n\n      def handle_event(\"send_message\", %{\"message\" => message}, socket) do\n        chat = HyperLLM.Chat.append(socket.assigns.chat, message)\n\n        send(self(), :chat_completion)\n        \n        {:noreply, socket |> assign(chat: chat)}\n      end\n\n      def handle_info(:chat_completion, socket) do\n        with {:ok, response} <- HyperLLM.Chat.completion(socket.assigns.chat) do\n          chat = HyperLLM.Chat.append(socket.assigns.chat, response)\n          {:noreply, socket |> assign(chat: chat)}\n        end\n      end\n    end","ref":"HyperLLM.Chat.html#module-example"},{"type":"function","title":"HyperLLM.Chat.append/2","doc":"Append a message to the chat.","ref":"HyperLLM.Chat.html#append/2"},{"type":"function","title":"Examples - HyperLLM.Chat.append/2","doc":"iex> chat = HyperLLM.Chat.start(model: \"gpt-4o-mini\")\n    iex> HyperLLM.Chat.append(chat, [\"Hello\", \"World\"])\n    %HyperLLM.Chat{messages: [%HyperLLM.Chat.Message{role: :user, content: \"Hello\"}, %HyperLLM.Chat.Message{role: :user, content: \"World\"}], provider: HyperLLM.Provider.OpenAI, config: [model: \"gpt-4o-mini\"]}\n\n    iex> chat = HyperLLM.Chat.start(model: \"gpt-4o-mini\")\n    iex> HyperLLM.Chat.append(chat, \"Hello\")\n    %HyperLLM.Chat{messages: [%HyperLLM.Chat.Message{role: :user, content: \"Hello\"}], provider: HyperLLM.Provider.OpenAI, config: [model: \"gpt-4o-mini\"]}","ref":"HyperLLM.Chat.html#append/2-examples"},{"type":"function","title":"HyperLLM.Chat.append/3","doc":"","ref":"HyperLLM.Chat.html#append/3"},{"type":"function","title":"HyperLLM.Chat.completion/2","doc":"","ref":"HyperLLM.Chat.html#completion/2"},{"type":"type","title":"HyperLLM.Chat.config/0","doc":"","ref":"HyperLLM.Chat.html#t:config/0"},{"type":"function","title":"HyperLLM.Chat.start/1","doc":"Start a new chat.","ref":"HyperLLM.Chat.html#start/1"},{"type":"function","title":"Examples - HyperLLM.Chat.start/1","doc":"iex> HyperLLM.Chat.start(model: \"gpt-4o-mini\")\n  %HyperLLM.Chat{messages: [], provider: HyperLLM.Provider.OpenAI, config: [model: \"gpt-4o-mini\"]}","ref":"HyperLLM.Chat.html#start/1-examples"},{"type":"type","title":"HyperLLM.Chat.t/0","doc":"","ref":"HyperLLM.Chat.html#t:t/0"},{"type":"module","title":"HyperLLM.Provider.Anthropic","doc":"Anthropic provider.","ref":"HyperLLM.Provider.Anthropic.html"},{"type":"module","title":"HyperLLM.Provider.Groq","doc":"Groq provider.","ref":"HyperLLM.Provider.Groq.html"},{"type":"module","title":"HyperLLM.Provider.OpenAI","doc":"OpenAI provider.","ref":"HyperLLM.Provider.OpenAI.html"},{"type":"behaviour","title":"HyperLLM.Tool","doc":"Defines the behaviour that all workflow tool modules must implement.\n\nEach tool module must implement the `call/1` callback, which takes a keyword list\nof inputs and returns a tuple containing a result atom and output keyword list.","ref":"HyperLLM.Tool.html"},{"type":"callback","title":"HyperLLM.Tool.call/1","doc":"Executes the tool with the given input values.","ref":"HyperLLM.Tool.html#c:call/1"},{"type":"callback","title":"Parameters - HyperLLM.Tool.call/1","doc":"* `input` - A keyword list containing the tool-specific input values","ref":"HyperLLM.Tool.html#c:call/1-parameters"},{"type":"callback","title":"Returns - HyperLLM.Tool.call/1","doc":"* `{result, output}` - A tuple containing:\n    * `result` - An atom indicating the result of the tool execution (e.g., :ok, :error, :high, :low)\n    * `output` - A keyword list containing the tool's output values","ref":"HyperLLM.Tool.html#c:call/1-returns"},{"type":"extras","title":"HyperLLM","doc":"# HyperLLM\n\n[![CI](https://github.com/cgarvis/hyper_llm/actions/workflows/elixir.yml/badge.svg)](https://github.com/cgarvis/hyper_llm/actions/workflows/elixir.yml)\n[![License](https://img.shields.io/hexpm/l/hyper_llm.svg)](https://github.com/cgarvis/hyper_llm/blob/main/LICENSE.md)\n[![Version](https://img.shields.io/hexpm/v/hyper_llm.svg)](https://hex.pm/packages/hyper_llm)\n[![Hex Docs](https://img.shields.io/badge/documentation-gray.svg)](https://hexdocs.pm/hyper_llm)\n\nCall all LLM APIs using the OpenAI format","ref":"readme.html"},{"type":"extras","title":"Installation - HyperLLM","doc":"Add `hyper_llm` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:hyper_llm, \"~> 0.0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - HyperLLM","doc":"```elixir\n\nHyperLLM.Chat.start(model: \"gpt-4o-mini\")\n|> HyperLLM.Chat.append(:developer, \"You are a helpful assistant.\")\n|> HyperLLM.Chat.append(:user, \"Spell \\\"strawberry\\\"\")\n|> HyperLLM.Chat.completion()\n#=> {:ok, \"Strawberry. 🍓\"}\n```\n\nIf you are using Phoenix, you can use the `HyperLLM.Chat` module in your LiveView.\n\n```elixir\ndefmodule ChatLive do\n  use Phoenix.LiveView\n\n  def mount(params, session, socket) do\n    {:ok,\n    socket\n    |> assign(chat: HyperLLM.Chat.start(model: \"gpt-4o-mini\"))}\n  end\n\n  def handle_event(\"send_message\", %{\"message\" => message}, socket) do\n    chat = HyperLLM.Chat.append(socket.assigns.chat, message)\n\n    send(self(), :chat_completion)\n    \n    {:noreply, socket |> assign(chat: chat)}\n  end\n\n  def handle_info(:chat_completion, socket) do\n    with {:ok, response} <- HyperLLM.Chat.completion(socket.assigns.chat) do\n      chat = HyperLLM.Chat.append(socket.assigns.chat, response)\n      {:noreply, socket |> assign(chat: chat)}\n    end\n  end\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Providers - HyperLLM","doc":"- [x] OpenAI\n- [ ] Azure\n- [x] Anthropic\n- [ ] AWS SageMaker\n- [ ] AWS Bedrock\n- [ ] Google - Vertex AI\n- [ ] Google - Palm\n- [ ] Mistral AI\n- [ ] CloudFlare AI Workers\n- [ ] Cohere\n- [ ] Groq\n- [ ] Ollama\n- [ ] Vertex AI","ref":"readme.html#providers"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}